@@ -36,13 +36,12 @@
 
 #pragma once
 
+#include <arpa/nameser.h>
 #include <inttypes.h>
+#include <netinet/in.h>
 #include <stdarg.h>
 #include <stdbool.h>
 #include <stdio.h>
-
-#include <arpa/nameser.h>
-#include <netinet/in.h>
 #include <sys/types.h>
 
 /*
@@ -56,6 +55,8 @@
 #define LIBDEF_F(f)
 #endif /* ifdef LIBRPZ_INTERNAL */
 
+#define LIBRPZ_MAXDOMAIN 255
+
 /*
  * Response Policy Zone triggers.
  *	Comparisons of trigger precedences require
@@ -126,7 +127,7 @@ typedef struct librpz_prefix {
 typedef uint8_t librpz_dsize_t;
 typedef struct librpz_domain {
 	librpz_dsize_t size; /* of only .d */
-	uint8_t	       d[0]; /* variable length wire format */
+	uint8_t	       d[];  /* variable length wire format */
 } librpz_domain_t;
 
 /*
@@ -134,7 +135,7 @@ typedef struct librpz_domain {
  */
 typedef struct librpz_domain_buf {
 	librpz_dsize_t size;
-	uint8_t	       d[NS_MAXCDNAME];
+	uint8_t	       d[LIBRPZ_MAXDOMAIN];
 } librpz_domain_buf_t;
 
 /*
@@ -146,7 +147,7 @@ typedef struct {
 	uint16_t class;	   /* network byte order */
 	uint32_t ttl;	   /* network byte order */
 	uint16_t rdlength; /* network byte order */
-	uint8_t	 rdata[0]; /* variable length */
+	uint8_t	 rdata[];  /* variable length */
 } librpz_rr_t;
 
 /*
@@ -156,7 +157,7 @@ typedef struct {
 typedef uint32_t librpz_idx_t;
 #define LIBRPZ_IDX_NULL 0
 #define LIBRPZ_IDX_MIN	1
-#define LIBRPZ_IDX_BAD	((librpz_idx_t)-1)
+#define LIBRPZ_IDX_BAD	((librpz_idx_t) - 1)
 /**
  * Partial decoded results of a set of RPZ queries for a single DNS response
  * or iteration through the mapped file.
@@ -170,8 +171,7 @@ typedef struct librpz_result {
 	librpz_dznum_t	   dznum;   /* dnsrpzd zone number */
 	librpz_cznum_t	   cznum;   /* librpz client zone number */
 	librpz_trig_t	   trig : LIBRPZ_TRIG_SIZE;
-	bool		   log : 1; /* log rewrite given librpz_log_level
-				     * */
+	bool		   log	: 1; /* log rewrite at given log level */
 } librpz_result_t;
 
 /**
@@ -215,7 +215,7 @@ typedef struct {
 } librpz_emsg_t;
 
 #ifdef LIBRPZ_HAVE_ATTR
-#define LIBRPZ_UNUSED	__attribute__((unused))
+#define LIBRPZ_UNUSED	ISC_ATTR_UNUSED
 #define LIBRPZ_PF(f, l) __attribute__((format(printf, f, l)))
 #define LIBRPZ_NORET	__attribute__((__noreturn__))
 #else /* ifdef LIBRPZ_HAVE_ATTR */
@@ -227,14 +227,15 @@ typedef struct {
 typedef bool(librpz_parse_log_opt_t)(librpz_emsg_t *emsg, const char *arg);
 LIBDEF_F(parse_log_opt)
 
-typedef void(librpz_vpemsg_t)(librpz_emsg_t *emsg, const char *p, va_list args);
+typedef void(librpz_vpemsg_t)(librpz_emsg_t *emsg, const char *p, va_list args)
+	LIBRPZ_PF(2, 0);
 LIBDEF_F(vpemsg)
 typedef void(librpz_pemsg_t)(librpz_emsg_t *emsg, const char *p, ...)
 	LIBRPZ_PF(2, 3);
 LIBDEF_F(pemsg)
 
 typedef void(librpz_vlog_t)(librpz_log_level_t level, void *ctx, const char *p,
-			    va_list args);
+			    va_list args) LIBRPZ_PF(3, 0);
 LIBDEF_F(vlog)
 typedef void(librpz_log_t)(librpz_log_level_t level, void *ctx, const char *p,
 			   ...) LIBRPZ_PF(3, 4);
@@ -244,10 +245,10 @@ typedef void(librpz_fatal_t)(int ex_code, const char *p, ...) LIBRPZ_PF(2, 3);
 extern void
 librpz_fatal(int ex_code, const char *p, ...) LIBRPZ_PF(2, 3) LIBRPZ_NORET;
 
-typedef void(librpz_rpz_assert_t)(const char *file, unsigned line,
+typedef void(librpz_rpz_assert_t)(const char *file, unsigned int line,
 				  const char *p, ...) LIBRPZ_PF(3, 4);
 extern void
-librpz_rpz_assert(const char *file, unsigned line, const char *p, ...)
+librpz_rpz_assert(const char *file, unsigned int line, const char *p, ...)
 	LIBRPZ_PF(3, 4) LIBRPZ_NORET;
 
 typedef void(librpz_rpz_vassert_t)(const char *file, uint line, const char *p,
@@ -366,7 +367,7 @@ typedef struct librpz_client librpz_client_t;
  * @param mutex: pointer to the lock for the client handle
  * @param log_ctx: NULL or resolver's context log messages
  */
-typedef librpz_clist_t *(librpz_clist_create_t)(librpz_emsg_t  *emsg,
+typedef librpz_clist_t *(librpz_clist_create_t)(librpz_emsg_t * emsg,
 						librpz_mutex_t *lock,
 						librpz_mutex_t *unlock,
 						librpz_mutex_t *mutex_destroy,
@@ -387,7 +388,7 @@ LIBDEF_F(clist_detach)
  * @param use_expired: true to not ignore expired zones
  * @return client handle or NULL if the handle could not be created
  */
-typedef librpz_client_t *(librpz_client_create_t)(librpz_emsg_t	 *emsg,
+typedef librpz_client_t *(librpz_client_create_t)(librpz_emsg_t * emsg,
 						  librpz_clist_t *clist,
 						  const char	 *cstr,
 						  bool		  use_expired);
@@ -648,8 +649,8 @@ LIBDEF_F(zone_refresh)
  * @param client context
  * @return malloc'ed string or NULL after error
  */
-typedef char *(librpz_db_info_t)(librpz_emsg_t *emsg, bool license, bool cfiles,
-				 bool listens, librpz_rsp_t *rsp);
+typedef char *(librpz_db_info_t)(librpz_emsg_t * emsg, bool license,
+				 bool cfiles, bool listens, librpz_rsp_t *rsp);
 LIBDEF_F(db_info)
 
 /**
@@ -669,7 +670,7 @@ LIBDEF_F(itr_start)
  * @param rsp state from librpz_itr_start()
  * @return malloc'ed string or NULL after error
  */
-typedef char *(librpz_mf_stats_t)(librpz_emsg_t *emsg, librpz_rsp_t *rsp);
+typedef char *(librpz_mf_stats_t)(librpz_emsg_t * emsg, librpz_rsp_t *rsp);
 LIBDEF_F(mf_stats)
 
 /**
@@ -678,7 +679,7 @@ LIBDEF_F(mf_stats)
  * @param[in,out] rsp: state from librpz_itr_start()
  * @return malloc'ed string or NULL after error
  */
-typedef char *(librpz_vers_stats_t)(librpz_emsg_t *emsg, librpz_rsp_t *rsp);
+typedef char *(librpz_vers_stats_t)(librpz_emsg_t * emsg, librpz_rsp_t *rsp);
 LIBDEF_F(vers_stats)
 
 /**
@@ -688,7 +689,7 @@ LIBDEF_F(vers_stats)
  * @param[in,out] rsp state from librpz_rsp_start()
  * @return malloc'ed string or NULL after error
  */
-typedef char *(librpz_itr_zone_t)(librpz_emsg_t *emsg, bool all_zones,
+typedef char *(librpz_itr_zone_t)(librpz_emsg_t * emsg, bool all_zones,
 				  librpz_rsp_t *rsp);
 LIBDEF_F(itr_zone)
 
@@ -755,11 +756,12 @@ typedef int(librpz_domain_pton2_t)(const char *src, u_char *dst, size_t dstsiz,
 LIBDEF_F(domain_pton2)
 
 typedef union socku socku_t;
-typedef socku_t *(librpz_mk_inet_su_t)(socku_t *su, const struct in_addr *addrp,
-				       in_port_t port);
+typedef socku_t *(librpz_mk_inet_su_t)(socku_t * su,
+				       const struct in_addr *addrp,
+				       in_port_t	     port);
 LIBDEF_F(mk_inet_su)
 
-typedef socku_t *(librpz_mk_inet6_su_t)(socku_t		      *su,
+typedef socku_t *(librpz_mk_inet6_su_t)(socku_t * su,
 					const struct in6_addr *addrp,
 					uint32_t scope_id, in_port_t port);
 LIBDEF_F(mk_inet6_su)
@@ -846,7 +848,7 @@ extern librpz_0_t librpz_def_0;
 typedef librpz_0_t librpz_t;
 extern librpz_t	  *librpz;
 
-#if LIBRPZ_LIB_OPEN == 2
+#if DNSRPS_LIB_OPEN == 2
 #include <dlfcn.h>
 
 /**
@@ -870,7 +872,7 @@ librpz_lib_open(librpz_emsg_t *emsg, void **dl_handle, const char *path) {
 		if (dlclose(*dl_handle) != 0) {
 			snprintf(emsg->c, sizeof(librpz_emsg_t),
 				 "dlopen(NULL): %s", dlerror());
-			return (NULL);
+			return NULL;
 		}
 		*dl_handle = NULL;
 	}
@@ -886,40 +888,42 @@ librpz_lib_open(librpz_emsg_t *emsg, void **dl_handle, const char *path) {
 		if (new_librpz != NULL) {
 			if (dl_handle != NULL) {
 				*dl_handle = handle;
+				handle = NULL;
 			}
-			return (new_librpz);
+			return new_librpz;
 		}
 		if (dlclose(handle) != 0) {
 			snprintf(emsg->c, sizeof(librpz_emsg_t),
 				 "dlsym(NULL, " LIBRPZ_DEF_STR "): %s",
 				 dlerror());
-			return (NULL);
+			return NULL;
 		}
 	}
 
 	if (path == NULL || path[0] == '\0') {
 		snprintf(emsg->c, sizeof(librpz_emsg_t),
 			 "librpz not linked and no dlopen() path provided");
-		return (NULL);
+		return NULL;
 	}
 
 	handle = dlopen(path, RTLD_NOW | RTLD_LOCAL);
 	if (handle == NULL) {
 		snprintf(emsg->c, sizeof(librpz_emsg_t), "dlopen(%s): %s", path,
 			 dlerror());
-		return (NULL);
+		return NULL;
 	}
 	new_librpz = dlsym(handle, LIBRPZ_DEF_STR);
 	if (new_librpz != NULL) {
 		if (dl_handle != NULL) {
 			*dl_handle = handle;
+			handle = NULL;
 		}
-		return (new_librpz);
+		return new_librpz;
 	}
 	snprintf(emsg->c, sizeof(librpz_emsg_t),
 		 "dlsym(%s, " LIBRPZ_DEF_STR "): %s", path, dlerror());
 	dlclose(handle);
-	return (NULL);
+	return NULL;
 }
 #elif defined(LIBRPZ_LIB_OPEN)
 /*
@@ -933,13 +937,13 @@ librpz_lib_open(librpz_emsg_t *emsg, void **dl_handle, const char *path) {
 		*dl_handle = NULL;
 	}
 
-#if LIBRPZ_LIB_OPEN == 1
+#if DNSRPS_LIB_OPEN == 1
 	emsg->c[0] = '\0';
-	return (&LIBRPZ_DEF);
-#else  /* if LIBRPZ_LIB_OPEN == 1 */
+	return &LIBRPZ_DEF;
+#else  /* if DNSRPS_LIB_OPEN == 1 */
 	snprintf(emsg->c, sizeof(librpz_emsg_t),
 		 "librpz not available via ./configure");
-	return (NULL);
-#endif /* LIBRPZ_LIB_OPEN */
+	return NULL;
+#endif /* DNSRPS_LIB_OPEN */
 }
 #endif /* LIBRPZ_LIB_OPEN */
